@@ -9,6 +9,9 @@
 #' @param n_mc Number of Monte-Carlo years.
 #' @param areas Areas to use in scenario builder, if `NULL` (default) all areas in Antares study are used.
 #' @param areas_rand Areas for which to use `"rand"`.
+#' @param group_bc `character` Bindgind constraints's groups names to use.
+#' @param group_bc_rand `character` Bindgind constraints which to use `"rand"`.
+#' @param mode `character` "bc" to edit binding constraints.
 #' @param coef_hydro_levels Hydro levels coefficients.
 #' @param opts
 #'   List of simulation parameters returned by the function
@@ -59,6 +62,17 @@
 #'   )
 #' )
 #' 
+#' # Create a scenario builder matrix with 
+#'  # bindings constraints groups (study version >= 8.7.0)
+#'   # Use parameter "mode" with "bc"   
+#' sbuilder <- scenarioBuilder(
+#'   n_scenario = 51,
+#'   n_mc = 2040,
+#'   group_bc = c("my_bc_1", "my_bc_2"), 
+#'   group_bc_rand = "my_bc_2",
+#'   mode = "bc"
+#' )
+#' 
 #' # Read previous scenario builder
 #' # in a matrix format
 #' prev_sb <- readScenarioBuilder()
@@ -72,6 +86,8 @@
 #' # equivalent as
 #' updateScenarioBuilder(ldata = list(l = sbuilder))
 #' 
+#' # for binding constraints (study version >= 8.7.0)
+#' updateScenarioBuilder(ldata = sbuilder, series = "bc")
 #' 
 #' # update several series
 #' 
@@ -93,54 +109,149 @@
 #' 
 #' deduplicateScenarioBuilder()
 #' }
-scenarioBuilder <- function(n_scenario, 
+scenarioBuilder <- function(n_scenario = 1, 
                             n_mc = NULL,
                             areas = NULL,
                             areas_rand = NULL,
+                            group_bc = NULL, 
+                            group_bc_rand = NULL,
                             coef_hydro_levels = NULL,
+                            mode = NULL,
                             opts = antaresRead::simOptions()) {
   
+  
   if (is_api_study(opts) && is_api_mocked(opts)) {
     stopifnot("In mocked API mode, n_mc cannot be NULL" = !is.null(n_mc))
-    stopifnot("In mocked API mode, areas cannot be NULL" = !is.null(n_mc))
+    stopifnot("In mocked API mode, areas cannot be NULL" = !is.null(areas))
   }
-  if (is.null(areas)) {
-    areas <- antaresRead::getAreas(opts = opts)
+  
+  if(n_scenario %in% 1)
+    warning("'n_scenario' parameter set to default value {1}", call. = FALSE)
+  
+  # check version >=870 from group parameter
+  if(!opts$antaresVersion >= 870 & !is.null(group_bc))
+    stop("Parameter 'group_bc' is only for Antares study version >= v8.7.0", 
+         call. = FALSE)
+  if(!opts$antaresVersion >= 870 & !is.null(group_bc_rand))
+    stop("Parameter 'group_bc_rand' is only for Antares study version >= v8.7.0", 
+         call. = FALSE)
+  
+  # >=v870
+  if(opts$antaresVersion >= 870){
+    # update with bc
+    if(!is.null(mode) && mode %in% "bc")
+      .manage_parameter_bc(n_scenario = n_scenario,
+                           n_mc = n_mc,
+                           group_bc = group_bc, 
+                           group_bc_rand = group_bc_rand, 
+                           opts = opts)
+    else # without bc
+      .manage_parameter(n_scenario = n_scenario,
+                        n_mc = n_mc,
+                        areas = areas,
+                        areas_rand = areas_rand,
+                        coef_hydro_levels = coef_hydro_levels,
+                        opts = opts)
+  }
+  else # <v870
+    .manage_parameter(n_scenario = n_scenario,
+                      n_mc = n_mc,
+                      areas = areas,
+                      areas_rand = areas_rand,
+                      coef_hydro_levels = coef_hydro_levels,
+                      opts = opts)
+}
+
+# Private function of scenarioBuilder()
+  # <v870 paradigm 
+.manage_parameter <- function(..., opts){
+  args <- list(...)
+    
+  # automatic parameter management 
+  if (is.null(args$areas)) {
+    args$areas <- antaresRead::getAreas(opts = opts)
   } else {
-    areas <- unique(c(areas, areas_rand))
+    args$areas <- unique(c(args$areas, args$areas_rand))
   }
-  if (!all(areas_rand %in% areas)) {
+  if (!all(args$areas_rand %in% args$areas)) {
     warning("Some 'areas_rand' are not Antares' areas", call. = FALSE)
   }
-  if (is.null(n_mc)) {
-    n_mc <- opts$parameters$general$nbyears
+  if (is.null(args$n_mc)) {
+    args$n_mc <- opts$parameters$general$nbyears
   } else {
-    if (isTRUE(n_mc != opts$parameters$general$nbyears)) {
+    if (isTRUE(args$n_mc != opts$parameters$general$nbyears)) {
       warning("Specified number of Monte-Carlo years differ from the one in Antares general parameter", call. = FALSE)
     }
   }
   
-  if (!is.null(coef_hydro_levels)) {
-    nb_areas <- length(areas)
-    nb_coef_hydro_levels <- length(coef_hydro_levels)
+  # hydro levels part
+  if (!is.null(args$coef_hydro_levels)) {
+    nb_areas <- length(args$areas)
+    nb_coef_hydro_levels <- length(args$coef_hydro_levels)
     if (nb_coef_hydro_levels == nb_areas) {
-      data_mat <- rep(coef_hydro_levels, each = n_mc)
-    } else if(nb_coef_hydro_levels == nb_areas * n_mc) {
-      data_mat <- coef_hydro_levels
+      data_mat <- rep(args$coef_hydro_levels, each = args$n_mc)
+    } else if(nb_coef_hydro_levels == nb_areas * args$n_mc) {
+      data_mat <- args$coef_hydro_levels
     } else {
       stop("Please check the number of areas and the number of coefficients for hydro levels that you provided.")
     }
   } else {
-    data_mat <- rep(rep_len(seq_len(n_scenario), n_mc), length(areas))
+    data_mat <- rep(rep_len(seq_len(args$n_scenario), 
+                            args$n_mc), 
+                    length(args$areas))
   }
   
   sb <- matrix(
     data = data_mat,
     byrow = TRUE, 
-    nrow = length(areas),
-    dimnames = list(areas, NULL)
+    nrow = length(args$areas),
+    dimnames = list(args$areas, NULL)
   )
-  sb[areas %in% areas_rand, ] <- "rand"
+  sb[args$areas %in% args$areas_rand, ] <- "rand"
+  
+  return(sb)
+}
+
+# Private function of scenarioBuilder()
+  # >=v870 paradigm 
+.manage_parameter_bc <- function(..., opts){
+  args <- list(...)
+  
+  # read groups
+  if(is.null(args$group_bc)){
+    args$group_bc <- readBindingConstraints(opts = opts)
+    args$group_bc <- sapply(group_bc, function(x){
+      x$properties$group
+      })
+  }
+  else 
+    group_bc <- unique(c(args$group_bc, args$group_bc_rand))
+  
+  # check parameters
+  if (!all(args$group_bc_rand %in% args$group_bc)) 
+    warning("Some 'group_bc_rand' are not Antares 'group_bc'", 
+            call. = FALSE)
+  
+  # n_mc parameter
+  if (is.null(args$n_mc)) 
+    args$n_mc <- opts$parameters$general$nbyears
+  else 
+    if (isTRUE(args$n_mc != opts$parameters$general$nbyears)) 
+      warning("Specified number of Monte-Carlo years differ from the one in Antares general parameter", 
+              call. = FALSE)
+  
+  # write data
+  data_mat <- rep(rep_len(seq_len(args$n_scenario), 
+                          args$n_mc),
+                  length(args$group_bc))
+  
+  sb <- matrix(
+    data = data_mat,
+    byrow = TRUE, 
+    nrow = length(args$group_bc),
+    dimnames = list(args$group_bc, NULL)
+  )
+  sb[args$group_bc %in% args$group_bc_rand, ] <- "rand"
   
   return(sb)
 }
@@ -148,10 +259,11 @@ scenarioBuilder <- function(n_scenario,
 
 #' @title Create the correspondence data frame between the symbol and the type in scenario builder
 #' @return a `data.frame`.
+#' @export
 create_scb_referential_series_type <- function(){
   
-  series_to_write <- c("l", "h", "w", "s", "t", "r", "ntc", "hl")
-  choices <- c("load", "hydro", "wind", "solar", "thermal", "renewables", "ntc", "hydrolevels")
+  series_to_write <- c("l", "h", "w", "s", "t", "r", "ntc", "hl", "bc")
+  choices <- c("load", "hydro", "wind", "solar", "thermal", "renewables", "ntc", "hydrolevels", "binding")
   
   # Check data consistency
   len_series_to_write <- length(series_to_write)  
@@ -165,7 +277,6 @@ create_scb_referential_series_type <- function(){
                            "choices" = rep(choices, 2),
                            "type" = c(rep("w",len_series_to_write), rep("r",len_choices))
                           )
-
   return(ref_series)
 }
 
@@ -183,29 +294,33 @@ create_scb_referential_series_type <- function(){
 readScenarioBuilder <- function(ruleset = "Default Ruleset",
                                 as_matrix = TRUE,
                                 opts = antaresRead::simOptions()) {
-  assertthat::assert_that(inherits(opts, "simOptions"))
+assertthat::assert_that(inherits(opts, "simOptions"))
+  
+  # read existing scenariobuilder.dat
   if (is_api_study(opts)) {
     if (is_api_mocked(opts)) {
       sb <- list("Default Ruleset" = NULL)
     } else {
-      sb <- readIni("settings/scenariobuilder", opts = opts, default_ext = ".dat")
+      sb <- readIni("settings/scenariobuilder", 
+                    opts = opts, default_ext = ".dat")
     }
   } else {
-    sb <- readIni("settings/scenariobuilder", opts = opts, default_ext = ".dat")
+    sb <- readIni("settings/scenariobuilder", 
+                  opts = opts, default_ext = ".dat")
   }
+  
+  # check structure in top of file scenariobuilder.dat
   if (!ruleset %in% names(sb)) {
-    warning(sprintf("Ruleset '%s' not found, possible values are: %s", ruleset, paste(names(sb), collapse = ", ")), call. = FALSE)
+    warning(sprintf("Ruleset '%s' not found, possible values are: %s", 
+                    ruleset, paste(names(sb), collapse = ", ")), 
+            call. = FALSE)
     sb <- NULL
   } else {
     sb <- sb[[ruleset]]
   }
   if (is.null(sb))
     return(list())
-  extract_el <- function(l, indice) {
-    res <- strsplit(x = names(l), split = ",")
-    res <- lapply(res, `[`, i = indice)
-    unlist(res)
-  }
+ 
   types <- extract_el(sb, 1)
   sbt <- split(x = sb, f = types)
   if (is_active_RES(opts)) {
@@ -218,57 +333,89 @@ readScenarioBuilder <- function(ruleset = "Default Ruleset",
     X = sbt,
     FUN = function(x) {
       type <- extract_el(x, 1)[1]
-      areas <- extract_el(x, 2)
-      if (type %in% c("t", "r")) {
-        clusters <- extract_el(x, 4)
-        areas <- paste(areas, clusters, sep = "_")
-        # all_areas <- areas # for the moment
-        if (type == "t") {
-          clusdesc <- readClusterDesc(opts = opts)
-        } else {
-          if (packageVersion("antaresRead") < "2.2.8")
-            stop("You need to install a more recent version of antaresRead (>2.2.8)", call. = FALSE)
-          if (!exists("readClusterResDesc", where = "package:antaresRead", mode = "function"))
-            stop("You need to install a more recent version of antaresRead (>2.2.8)", call. = FALSE)
-          read_cluster_res_desc <- getFromNamespace("readClusterResDesc", ns = "antaresRead")
-          clusdesc <- read_cluster_res_desc(opts = opts)
-        }
-        all_areas <- paste(clusdesc$area, clusdesc$cluster, sep = "_")
-      } else {
-        all_areas <- getAreas(opts = opts)
-      }
-      if (type %in% c("ntc")) {
-        areas2 <- extract_el(x, 3)
-        areas <- paste(areas, areas2, sep = "%")
-        years <- extract_el(x, 4)
-      } else {
-        years <- extract_el(x, 3)
-      }
       
-      if (as_matrix) {
-        SB <- data.table(
-          areas = areas,
-          years = as.numeric(years) + 1,
-          values = unlist(x, use.names = FALSE)
-        )
-        if (!type %in% c("ntc")) {
-          SB <- SB[CJ(areas = all_areas, years = seq_len(opts$parameters$general$nbyears)), on = c("areas", "years")]
+      # >= v870 : scenarized binding constraints 
+      if(type %in% "bc"){
+        # extract informations for matrix output
+        bc_groups <- extract_el(x, 2)
+        years <- extract_el(x, 3)
+        
+        # output format
+        if (as_matrix) {
+          SB <- data.table(
+            group = bc_groups,
+            years = as.numeric(years) + 1,
+            values = unlist(x, use.names = FALSE)
+          )
+   
+          SB <- dcast(data = SB, 
+                      formula = group ~ years, 
+                      value.var = "values")
+          mat <- as.matrix(SB, rownames = 1)
+          colnames(mat) <- NULL
+          mat
+        } else 
+          x
+      }else{
+        areas <- extract_el(x, 2)
+        if (type %in% c("t", "r")) {
+          clusters <- extract_el(x, 4)
+          areas <- paste(areas, clusters, sep = "_")
+          # all_areas <- areas # for the moment
+          if (type == "t") {
+            clusdesc <- readClusterDesc(opts = opts)
+          } else {
+            if (packageVersion("antaresRead") < "2.2.8")
+              stop("You need to install a more recent version of antaresRead (>2.2.8)", call. = FALSE)
+            if (!exists("readClusterResDesc", where = "package:antaresRead", mode = "function"))
+              stop("You need to install a more recent version of antaresRead (>2.2.8)", call. = FALSE)
+            read_cluster_res_desc <- getFromNamespace("readClusterResDesc", ns = "antaresRead")
+            clusdesc <- read_cluster_res_desc(opts = opts)
+          }
+          all_areas <- paste(clusdesc$area, clusdesc$cluster, sep = "_")
+        } else {
+          all_areas <- getAreas(opts = opts)
+        }
+        if (type %in% c("ntc")) {
+          areas2 <- extract_el(x, 3)
+          areas <- paste(areas, areas2, sep = "%")
+          years <- extract_el(x, 4)
+        } else {
+          years <- extract_el(x, 3)
+        }
+        
+        if (as_matrix) {
+          SB <- data.table(
+            areas = areas,
+            years = as.numeric(years) + 1,
+            values = unlist(x, use.names = FALSE)
+          )
+          if (!type %in% c("ntc")) {
+            SB <- SB[CJ(areas = all_areas, years = seq_len(opts$parameters$general$nbyears)), on = c("areas", "years")]
+          }
+          SB <- dcast(data = SB, formula = areas ~ years, value.var = "values")
+          mat <- as.matrix(SB, rownames = 1)
+          colnames(mat) <- NULL
+          mat
+        } else {
+          x
         }
-        SB <- dcast(data = SB, formula = areas ~ years, value.var = "values")
-        mat <- as.matrix(SB, rownames = 1)
-        colnames(mat) <- NULL
-        mat
-      } else {
-        x
       }
+    
     }
   )
 }
 
+extract_el <- function(l, indice) {
+  res <- strsplit(x = names(l), split = ",")
+  res <- lapply(res, `[`, i = indice)
+  unlist(res)
+}
+
 
 #' @param ldata A `matrix` obtained with `scenarioBuilder`, 
 #'  or a named list of matrices obtained with `scenarioBuilder`, names must be 
-#'  'l', 'h', 'w', 's', 't', 'r', 'ntc' or 'hl', depending on the series to update.
+#'  'l', 'h', 'w', 's', 't', 'r', 'ntc', 'hl' or 'bc', depending on the series to update.
 #' @param series Name(s) of the serie(s) to update if `ldata` is a single `matrix`.
 #' @param clusters_areas A `data.table` with two columns `area` and `cluster`
 #'  to identify area/cluster couple to update for thermal or renewable series.
@@ -281,7 +428,8 @@ readScenarioBuilder <- function(ruleset = "Default Ruleset",
 #' @note
 #'  - `series = "ntc"` is only available with Antares >= 8.2.0.
 #'  - For `series = "hl"`, each value must be between 0 and 1.
-#'  - User must enable/disable `custom-scenario` property in `settings/generaldata.ini` by himself.
+#'  - User must enable/disable `custom-scenario` property in `settings/generaldata.ini` by himself.  
+#'  - `series = "bc"` is only available with Antares >= 8.7.0.
 #'
 #' For a single matrix, value of series can be :
 #'  - h or hydro
@@ -305,7 +453,10 @@ updateScenarioBuilder <- function(ldata,
   
   assertthat::assert_that(inherits(opts, "simOptions"))
   
-  suppressWarnings(prevSB <- readScenarioBuilder(ruleset = ruleset, as_matrix = FALSE, opts = opts))
+  suppressWarnings(
+    prevSB <- readScenarioBuilder(ruleset = ruleset, 
+                                  as_matrix = FALSE, 
+                                  opts = opts))
   
   ref_series <- create_scb_referential_series_type()
   
@@ -317,6 +468,9 @@ updateScenarioBuilder <- function(ldata,
       choices <- ref_series[ref_series$series %in% series, "choices"]
       if (isTRUE("ntc" %in% series) & isTRUE(opts$antaresVersion < 820))
         stop("updateScenarioBuilder: cannot use series='ntc' with Antares < 8.2.0", call. = FALSE)
+      if (isTRUE("bc" %in% series) & isTRUE(opts$antaresVersion < 870))
+        stop("updateScenarioBuilder: cannot use series='bc' with Antares < 8.7.0", 
+             call. = FALSE)
       series <- ref_series[ref_series$choices %in% choices & ref_series$type == "w", "series"]
     } else {
       stop("If 'ldata' isn't a named list, you must specify which serie(s) to use!", call. = FALSE)
@@ -338,6 +492,9 @@ updateScenarioBuilder <- function(ldata,
     }
     if (isTRUE("ntc" %in% series) & isTRUE(opts$antaresVersion < 820))
       stop("updateScenarioBuilder: cannot use series='ntc' with Antares < 8.2.0", call. = FALSE)
+    if (isTRUE("bc" %in% series) & isTRUE(opts$antaresVersion < 870))
+      stop("updateScenarioBuilder: cannot use series='bc' with Antares < 8.7.0", 
+           call. = FALSE)
     sbuild <- lapply(
       X = series,
       FUN = function(x) {
@@ -419,7 +576,7 @@ clearScenarioBuilder <- function(ruleset = "Default Ruleset",
 #' Converts a scenarioBuilder matrix to a list
 #' 
 #' @param mat A matrix obtained from scenarioBuilder().
-#' @param series Name of the series, among 'l', 'h', 'w', 's', 't', 'r', 'ntc' and 'hl'.
+#' @param series Name of the series, among 'l', 'h', 'w', 's', 't', 'r', 'ntc', 'hl', 'bc'.
 #' @param clusters_areas A `data.table` with two columns `area` and `cluster`
 #'  to identify area/cluster couple to use for thermal or renewable series.
 #' @param links Either a simple vector with links described as `"area01%area02` or a `data.table` with two columns `from` and `to`.
