@@ -106,21 +106,6 @@ test_that("Create cluster with pollutants params (new feature v8.6)",{
   
   createArea(name = "test")
   
-  test_that("Create cluster default call (new feature v8.6)",{
-    # default call now create without pollutants
-    createCluster(area = getAreas()[1],
-                  cluster_name = "cluster_default",
-                  overwrite = TRUE)
-    
-    res_cluster <- antaresRead::readClusterDesc()
-    
-    pollutants_names <- names(antaresEditObject::list_pollutants_values())
-    
-    # check default values 
-    testthat::expect_false(all(
-      pollutants_names %in% names(res_cluster)))
-  })
-  
   test_that("Create cluster with bad parameter pollutant",{
     bad_pollutants_param <- "not_a_list"
     
@@ -226,9 +211,8 @@ test_that("removeCluster() : cluster is not removed if it is referenced in a bin
   
   suppressWarnings(opts <- setSimulationPath(path = opts$studyPath, simulation = "input"))
   
-  expect_error(removeCluster(area = "zone1", cluster_name = "nuclear", add_prefix = TRUE, opts = opts), regexp = "Can not remove the cluster")
-  removeBindingConstraint(name = "bc_nuclear", opts = opts)
-  expect_no_error(removeCluster(area = "zone1", cluster_name = "nuclear", add_prefix = TRUE, opts = opts))
+  expect_warning(removeCluster(area = "zone1", cluster_name = "nuclear", add_prefix = TRUE, opts = opts),
+                 regexp = "The following binding constraints have the cluster to remove as a coefficient :")
   
   unlink(x = opts$studyPath, recursive = TRUE)
 })
